@@ -1,3 +1,3 @@
 package My::ResultBaseClass;
-use base 'DBIx::Class';
+use base 'DBIx::Class::Core';
 1;
